IntentionC2s

Struct IntentionC2s 

pub struct IntentionC2s<'a> {
    pub protocol_version: VarInt,
    pub server_address: Bounded<&'a str, 255>,
    pub server_port: u16,
    pub intent: HandShakeIntent,
}
This packet causes the server to switch into the target state. It should be sent right after opening the TCP connection to prevent the server from disconnecting.

Fields

protocol_version: VarIntserver_address: Bounded<&'a str, 255>server_port: u16intent: HandShakeIntent