pub struct IntentionC2s<'a> {
pub protocol_version: VarInt,
pub server_address: Bounded<&'a str, 255>,
pub server_port: u16,
pub intent: HandShakeIntent,
}Expand description
This packet causes the server to switch into the target state. It should be sent right after opening the TCP connection to prevent the server from disconnecting.
Fields
protocol_version: VarIntserver_address: Bounded<&'a str, 255>server_port: u16intent: HandShakeIntentTrait Implementations
Sourceimpl<'a> Clone for IntentionC2s<'a>
impl<'a> Clone for IntentionC2s<'a>
Sourcefn clone(&self) -> IntentionC2s<'a>
fn clone(&self) -> IntentionC2s<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for IntentionC2s<'a>
impl<'a> Debug for IntentionC2s<'a>
Sourceimpl<'a> Decode<'a> for IntentionC2s<'a>
impl<'a> Decode<'a> for IntentionC2s<'a>
Sourceimpl<'a> Encode for IntentionC2s<'a>
impl<'a> Encode for IntentionC2s<'a>
Sourceimpl<'a> Packet for IntentionC2s<'a>
impl<'a> Packet for IntentionC2s<'a>
Sourceconst SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Serverbound
const SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Serverbound
The side this packet is intended for.
Sourceconst STATE: PacketState = PacketState::Handshake
const STATE: PacketState = PacketState::Handshake
The state in which this packet is used.